@@ -4,13 +4,13 @@ use std::ffi::OsStr;
 use std::fs;
 use std::path::{Path, PathBuf};
 
-/// Continually go up in the file tree until a manifest (Forc.toml) is found.
+/// Continually go up in the file tree until a specified file is found.
 #[allow(clippy::branches_sharing_code)]
-pub fn find_manifest_dir(starter_path: &Path) -> Option<PathBuf> {
+pub fn find_parent_dir_with_file(starter_path: &Path, file_name: &str) -> Option<PathBuf> {
     let mut path = std::fs::canonicalize(starter_path).ok()?;
     let empty_path = PathBuf::from("/");
     while path != empty_path {
-        path.push(crate::constants::MANIFEST_FILE_NAME);
+        path.push(file_name);
         if path.exists() {
             path.pop();
             return Some(path);
@@ -21,6 +21,14 @@ pub fn find_manifest_dir(starter_path: &Path) -> Option<PathBuf> {
     }
     None
 }
+/// Continually go up in the file tree until a Forc manifest file is found.
+pub fn find_manifest_dir(starter_path: &Path) -> Option<PathBuf> {
+    find_parent_dir_with_file(starter_path, constants::MANIFEST_FILE_NAME)
+}
+/// Continually go up in the file tree until a Cargo manifest file is found.
+pub fn find_cargo_manifest_dir(starter_path: &Path) -> Option<PathBuf> {
+    find_parent_dir_with_file(starter_path, "Cargo.toml")
+}
 pub fn get_sway_files(path: PathBuf) -> Vec<PathBuf> {
     let mut files = vec![];
     let mut dir_entries = vec![path];
